@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-__version__ = '0.9.7'
-__timestamp__ = 'Wed May 5 14:14:24 2021 +0100'
+__version__ = '0.9.8'
+__timestamp__ = 'Thu Jun 17 15:37:50 2021 +0100'
 __license__ = '''
                                  Apache License
                            Version 2.0, January 2004
